

DALService
=========================

.. currentmodule:: pyvo.dal.query

.. autoclass:: DALService
   :show-inheritance:

   
     
   

   
   

   .. rubric:: Attributes Summary

   .. autosummary::
   
      ~DALService.baseurl
      ~DALService.info
      ~DALService.protocol
      ~DALService.version

   
   

   
   

   .. rubric:: Methods Summary

   .. autosummary::
   
      ~DALService.create_query
      ~DALService.describe
      ~DALService.search

   
   

   
   

   .. rubric:: Attributes Documentation

   
   .. autoattribute:: baseurl
   .. autoattribute:: info
   .. autoattribute:: protocol
   .. autoattribute:: version

   
   

   
   

   .. rubric:: Methods Documentation

   
   .. automethod:: create_query
   .. automethod:: describe
   .. automethod:: search

   
   